==> nextcloud-30.0.15.tgz: nextcloud/apps/files_downloadlimit/l10n/fr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limite de téléchargement de fichiers",
    "File link share download limit" : "Limite de téléchargement de fichier partagé par lien",
    "This app allows limiting the number of downloads for external link shares." : "Cette application permet de limiter le nombre de téléchargements pour les partages de liens externes. ",
    "The minimum limit is 1" : "La limite minimum est de 1",
    "Failed to set download limit" : "Échec de définition de la limite de téléchargement",
    "Failed to remove download limit" : "Échec de suppression de la limite de téléchargement",
    "Limit downloads" : "Limiter le nombre de téléchargements",
    "Set download limit" : "Définir le nombre maximal de téléchargements autorisés",
    "Setting a new limit will reset the download count" : "Définir une nouvelle limite réinitialisera le compteur de téléchargement",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 téléchargement autorisé restant","{count} téléchargements autorisés restants","{count} téléchargements autorisés restants"],
    "Failed to set default download limit" : "Échec de définition de la limite de téléchargement par défaut",
    "Download limit" : "Limite de téléchargements",
    "Configure the default download limit for external shares." : "Configuration de la limite par défaut de téléchargement pour les partages externes.",
    "Set default download limit" : "Définir la limite de téléchargement par défaut",
    "You have reached the maximum amount of downloads allowed" : "Vous avez atteint le nombre maximal de téléchargements autorisés.",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Ce partage ne peut être téléchargé qu'un nombre limité de fois. Etes-vous certain de vouloir déclencher un nouveau téléchargement ?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.11.tgz: nextcloud/apps/files_downloadlimit/l10n/fr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limite de téléchargement de fichiers",
    "File link share download limit" : "Limite de téléchargement de fichier partagé par lien",
    "This app allows limiting the number of downloads for external link shares." : "Cette application permet de limiter le nombre de téléchargements pour les partages de liens externes. ",
    "The minimum limit is 1" : "La limite minimum est de 1",
    "Failed to set download limit" : "Échec de définition de la limite de téléchargement",
    "Failed to remove download limit" : "Échec de suppression de la limite de téléchargement",
    "Limit downloads" : "Limiter le nombre de téléchargements",
    "Set download limit" : "Définir le nombre maximal de téléchargements autorisés",
    "Setting a new limit will reset the download count" : "Définir une nouvelle limite réinitialisera le compteur de téléchargement",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 téléchargement autorisé restant","{count} téléchargements autorisés restants","{count} téléchargements autorisés restants"],
    "Download limit" : "Limite de téléchargements",
    "Configure the default download limit for external shares." : "Configuration de la limite par défaut de téléchargement pour les partages externes.",
    "Default download limit for external shares" : "Limite par défaut de téléchargement pour les partages externes",
    "Set default download limit" : "Définir la limite de téléchargement par défaut",
    "You have reached the maximum amount of downloads allowed" : "Vous avez atteint le nombre maximal de téléchargements autorisés.",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Ce partage ne peut être téléchargé qu'un nombre limité de fois. Etes-vous certain de vouloir déclencher un nouveau téléchargement ?",
    "Failed to set default download limit" : "Échec de définition de la limite de téléchargement par défaut",
    "Failed to remove default download limit" : "Échec de suppression de la limite par défaut de téléchargement"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
